@@ -1,5 +1,3 @@
-use vars qw( $BASE $SAMPLES );
-
 use Cwd;
 use File::Spec;
 my $pwd = cwd();
@@ -9,7 +7,7 @@ if (-f 'test-common.pl') {
 }
 elsif (-f 't/test-common.pl') {
 }
-$BASE = File::Spec->catdir(@pieces);
-$SAMPLES = File::Spec->catdir($BASE, 't', 'samples');
+our $BASE = File::Spec->catdir(@pieces);
+our $SAMPLES = File::Spec->catdir($BASE, 't', 'samples');
 
 1;
